@@ -13,13 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from typing import MutableMapping, MutableSequence
 
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.type import money_pb2  # type: ignore
 from google.type import postal_address_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.domains.v1",
@@ -132,10 +132,10 @@ class Registration(proto.Message):
             ``Registration``.
         state (google.cloud.domains_v1.types.Registration.State):
             Output only. The state of the ``Registration``
-        issues (Sequence[google.cloud.domains_v1.types.Registration.Issue]):
+        issues (MutableSequence[google.cloud.domains_v1.types.Registration.Issue]):
             Output only. The set of issues with the ``Registration``
             that require attention.
-        labels (Sequence[google.cloud.domains_v1.types.Registration.LabelsEntry]):
+        labels (MutableMapping[str, str]):
             Set of labels associated with the ``Registration``.
         management_settings (google.cloud.domains_v1.types.ManagementSettings):
             Settings for management of the ``Registration``, including
@@ -162,7 +162,7 @@ class Registration(proto.Message):
             been confirmed. To confirm the changes, the
             ``registrant_contact`` must follow the instructions in the
             email they receive.
-        supported_privacy (Sequence[google.cloud.domains_v1.types.ContactPrivacy]):
+        supported_privacy (MutableSequence[google.cloud.domains_v1.types.ContactPrivacy]):
             Output only. Set of options for the
             ``contact_settings.privacy`` field that this
             ``Registration`` supports.
@@ -185,23 +185,63 @@ class Registration(proto.Message):
         CONTACT_SUPPORT = 1
         UNVERIFIED_EMAIL = 2
 
-    name = proto.Field(proto.STRING, number=1,)
-    domain_name = proto.Field(proto.STRING, number=2,)
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    expire_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
-    state = proto.Field(proto.ENUM, number=7, enum=State,)
-    issues = proto.RepeatedField(proto.ENUM, number=8, enum=Issue,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=9,)
-    management_settings = proto.Field(
-        proto.MESSAGE, number=10, message="ManagementSettings",
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    dns_settings = proto.Field(proto.MESSAGE, number=11, message="DnsSettings",)
-    contact_settings = proto.Field(proto.MESSAGE, number=12, message="ContactSettings",)
-    pending_contact_settings = proto.Field(
-        proto.MESSAGE, number=13, message="ContactSettings",
+    domain_name: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    supported_privacy = proto.RepeatedField(
-        proto.ENUM, number=14, enum="ContactPrivacy",
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    expire_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
+    state: State = proto.Field(
+        proto.ENUM,
+        number=7,
+        enum=State,
+    )
+    issues: MutableSequence[Issue] = proto.RepeatedField(
+        proto.ENUM,
+        number=8,
+        enum=Issue,
+    )
+    labels: MutableMapping[str, str] = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=9,
+    )
+    management_settings: "ManagementSettings" = proto.Field(
+        proto.MESSAGE,
+        number=10,
+        message="ManagementSettings",
+    )
+    dns_settings: "DnsSettings" = proto.Field(
+        proto.MESSAGE,
+        number=11,
+        message="DnsSettings",
+    )
+    contact_settings: "ContactSettings" = proto.Field(
+        proto.MESSAGE,
+        number=12,
+        message="ContactSettings",
+    )
+    pending_contact_settings: "ContactSettings" = proto.Field(
+        proto.MESSAGE,
+        number=13,
+        message="ContactSettings",
+    )
+    supported_privacy: MutableSequence["ContactPrivacy"] = proto.RepeatedField(
+        proto.ENUM,
+        number=14,
+        enum="ContactPrivacy",
     )
 
 
@@ -223,8 +263,16 @@ class ManagementSettings(proto.Message):
         AUTOMATIC_RENEWAL = 1
         MANUAL_RENEWAL = 2
 
-    renewal_method = proto.Field(proto.ENUM, number=3, enum=RenewalMethod,)
-    transfer_lock_state = proto.Field(proto.ENUM, number=4, enum="TransferLockState",)
+    renewal_method: RenewalMethod = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=RenewalMethod,
+    )
+    transfer_lock_state: "TransferLockState" = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum="TransferLockState",
+    )
 
 
 class DnsSettings(proto.Message):
@@ -249,7 +297,7 @@ class DnsSettings(proto.Message):
             Domains <https://domains.google/>`__.
 
             This field is a member of `oneof`_ ``dns_provider``.
-        glue_records (Sequence[google.cloud.domains_v1.types.DnsSettings.GlueRecord]):
+        glue_records (MutableSequence[google.cloud.domains_v1.types.DnsSettings.GlueRecord]):
             The list of glue records for this ``Registration``. Commonly
             empty.
     """
@@ -264,21 +312,26 @@ class DnsSettings(proto.Message):
         r"""Configuration for an arbitrary DNS provider.
 
         Attributes:
-            name_servers (Sequence[str]):
+            name_servers (MutableSequence[str]):
                 Required. A list of name servers that store
                 the DNS zone for this domain. Each name server
                 is a domain name, with Unicode domain names
                 expressed in Punycode format.
-            ds_records (Sequence[google.cloud.domains_v1.types.DnsSettings.DsRecord]):
+            ds_records (MutableSequence[google.cloud.domains_v1.types.DnsSettings.DsRecord]):
                 The list of DS records for this domain, which
                 are used to enable DNSSEC. The domain's DNS
                 provider can provide the values to set here. If
                 this field is empty, DNSSEC is disabled.
         """
 
-        name_servers = proto.RepeatedField(proto.STRING, number=1,)
-        ds_records = proto.RepeatedField(
-            proto.MESSAGE, number=2, message="DnsSettings.DsRecord",
+        name_servers: MutableSequence[str] = proto.RepeatedField(
+            proto.STRING,
+            number=1,
+        )
+        ds_records: MutableSequence["DnsSettings.DsRecord"] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=2,
+            message="DnsSettings.DsRecord",
         )
 
     class GoogleDomainsDns(proto.Message):
@@ -288,7 +341,7 @@ class DnsSettings(proto.Message):
         `Google Domains <https://domains.google/>`__.
 
         Attributes:
-            name_servers (Sequence[str]):
+            name_servers (MutableSequence[str]):
                 Output only. A list of name servers that
                 store the DNS zone for this domain. Each name
                 server is a domain name, with Unicode domain
@@ -299,17 +352,26 @@ class DnsSettings(proto.Message):
                 Required. The state of DS records for this
                 domain. Used to enable or disable automatic
                 DNSSEC.
-            ds_records (Sequence[google.cloud.domains_v1.types.DnsSettings.DsRecord]):
+            ds_records (MutableSequence[google.cloud.domains_v1.types.DnsSettings.DsRecord]):
                 Output only. The list of DS records published for this
                 domain. The list is automatically populated when
                 ``ds_state`` is ``DS_RECORDS_PUBLISHED``, otherwise it
                 remains empty.
         """
 
-        name_servers = proto.RepeatedField(proto.STRING, number=1,)
-        ds_state = proto.Field(proto.ENUM, number=2, enum="DnsSettings.DsState",)
-        ds_records = proto.RepeatedField(
-            proto.MESSAGE, number=3, message="DnsSettings.DsRecord",
+        name_servers: MutableSequence[str] = proto.RepeatedField(
+            proto.STRING,
+            number=1,
+        )
+        ds_state: "DnsSettings.DsState" = proto.Field(
+            proto.ENUM,
+            number=2,
+            enum="DnsSettings.DsState",
+        )
+        ds_records: MutableSequence["DnsSettings.DsRecord"] = proto.RepeatedField(
+            proto.MESSAGE,
+            number=3,
+            message="DnsSettings.DsRecord",
         )
 
     class DsRecord(proto.Message):
@@ -365,14 +427,24 @@ class DnsSettings(proto.Message):
             GOST3411 = 3
             SHA384 = 4
 
-        key_tag = proto.Field(proto.INT32, number=1,)
-        algorithm = proto.Field(
-            proto.ENUM, number=2, enum="DnsSettings.DsRecord.Algorithm",
+        key_tag: int = proto.Field(
+            proto.INT32,
+            number=1,
         )
-        digest_type = proto.Field(
-            proto.ENUM, number=3, enum="DnsSettings.DsRecord.DigestType",
+        algorithm: "DnsSettings.DsRecord.Algorithm" = proto.Field(
+            proto.ENUM,
+            number=2,
+            enum="DnsSettings.DsRecord.Algorithm",
+        )
+        digest_type: "DnsSettings.DsRecord.DigestType" = proto.Field(
+            proto.ENUM,
+            number=3,
+            enum="DnsSettings.DsRecord.DigestType",
+        )
+        digest: str = proto.Field(
+            proto.STRING,
+            number=4,
         )
-        digest = proto.Field(proto.STRING, number=4,)
 
     class GlueRecord(proto.Message):
         r"""Defines a host on your domain that is a DNS name server for your
@@ -386,27 +458,46 @@ class DnsSettings(proto.Message):
             host_name (str):
                 Required. Domain name of the host in Punycode
                 format.
-            ipv4_addresses (Sequence[str]):
+            ipv4_addresses (MutableSequence[str]):
                 List of IPv4 addresses corresponding to this host in the
                 standard decimal format (e.g. ``198.51.100.1``). At least
                 one of ``ipv4_address`` and ``ipv6_address`` must be set.
-            ipv6_addresses (Sequence[str]):
+            ipv6_addresses (MutableSequence[str]):
                 List of IPv6 addresses corresponding to this host in the
                 standard hexadecimal format (e.g. ``2001:db8::``). At least
                 one of ``ipv4_address`` and ``ipv6_address`` must be set.
         """
 
-        host_name = proto.Field(proto.STRING, number=1,)
-        ipv4_addresses = proto.RepeatedField(proto.STRING, number=2,)
-        ipv6_addresses = proto.RepeatedField(proto.STRING, number=3,)
+        host_name: str = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        ipv4_addresses: MutableSequence[str] = proto.RepeatedField(
+            proto.STRING,
+            number=2,
+        )
+        ipv6_addresses: MutableSequence[str] = proto.RepeatedField(
+            proto.STRING,
+            number=3,
+        )
 
-    custom_dns = proto.Field(
-        proto.MESSAGE, number=1, oneof="dns_provider", message=CustomDns,
+    custom_dns: CustomDns = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        oneof="dns_provider",
+        message=CustomDns,
     )
-    google_domains_dns = proto.Field(
-        proto.MESSAGE, number=2, oneof="dns_provider", message=GoogleDomainsDns,
+    google_domains_dns: GoogleDomainsDns = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        oneof="dns_provider",
+        message=GoogleDomainsDns,
+    )
+    glue_records: MutableSequence[GlueRecord] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=4,
+        message=GlueRecord,
     )
-    glue_records = proto.RepeatedField(proto.MESSAGE, number=4, message=GlueRecord,)
 
 
 class ContactSettings(proto.Message):
@@ -454,17 +545,44 @@ class ContactSettings(proto.Message):
                 example, ``"+1-800-555-0123"``.
         """
 
-        postal_address = proto.Field(
-            proto.MESSAGE, number=1, message=postal_address_pb2.PostalAddress,
+        postal_address: postal_address_pb2.PostalAddress = proto.Field(
+            proto.MESSAGE,
+            number=1,
+            message=postal_address_pb2.PostalAddress,
+        )
+        email: str = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        phone_number: str = proto.Field(
+            proto.STRING,
+            number=3,
+        )
+        fax_number: str = proto.Field(
+            proto.STRING,
+            number=4,
         )
-        email = proto.Field(proto.STRING, number=2,)
-        phone_number = proto.Field(proto.STRING, number=3,)
-        fax_number = proto.Field(proto.STRING, number=4,)
 
-    privacy = proto.Field(proto.ENUM, number=1, enum="ContactPrivacy",)
-    registrant_contact = proto.Field(proto.MESSAGE, number=2, message=Contact,)
-    admin_contact = proto.Field(proto.MESSAGE, number=3, message=Contact,)
-    technical_contact = proto.Field(proto.MESSAGE, number=4, message=Contact,)
+    privacy: "ContactPrivacy" = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum="ContactPrivacy",
+    )
+    registrant_contact: Contact = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=Contact,
+    )
+    admin_contact: Contact = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=Contact,
+    )
+    technical_contact: Contact = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=Contact,
+    )
 
 
 class SearchDomainsRequest(proto.Message):
@@ -479,20 +597,28 @@ class SearchDomainsRequest(proto.Message):
             ``projects/*/locations/*``.
     """
 
-    query = proto.Field(proto.STRING, number=1,)
-    location = proto.Field(proto.STRING, number=2,)
+    query: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    location: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class SearchDomainsResponse(proto.Message):
     r"""Response for the ``SearchDomains`` method.
 
     Attributes:
-        register_parameters (Sequence[google.cloud.domains_v1.types.RegisterParameters]):
+        register_parameters (MutableSequence[google.cloud.domains_v1.types.RegisterParameters]):
             Results of the domain name search.
     """
 
-    register_parameters = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="RegisterParameters",
+    register_parameters: MutableSequence["RegisterParameters"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="RegisterParameters",
     )
 
 
@@ -508,8 +634,14 @@ class RetrieveRegisterParametersRequest(proto.Message):
             ``projects/*/locations/*``.
     """
 
-    domain_name = proto.Field(proto.STRING, number=1,)
-    location = proto.Field(proto.STRING, number=2,)
+    domain_name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    location: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class RetrieveRegisterParametersResponse(proto.Message):
@@ -521,8 +653,10 @@ class RetrieveRegisterParametersResponse(proto.Message):
             method.
     """
 
-    register_parameters = proto.Field(
-        proto.MESSAGE, number=1, message="RegisterParameters",
+    register_parameters: "RegisterParameters" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="RegisterParameters",
     )
 
 
@@ -536,11 +670,11 @@ class RegisterDomainRequest(proto.Message):
         registration (google.cloud.domains_v1.types.Registration):
             Required. The complete ``Registration`` resource to be
             created.
-        domain_notices (Sequence[google.cloud.domains_v1.types.DomainNotice]):
+        domain_notices (MutableSequence[google.cloud.domains_v1.types.DomainNotice]):
             The list of domain notices that you acknowledge. Call
             ``RetrieveRegisterParameters`` to see the notices that need
             acknowledgement.
-        contact_notices (Sequence[google.cloud.domains_v1.types.ContactNotice]):
+        contact_notices (MutableSequence[google.cloud.domains_v1.types.ContactNotice]):
             The list of contact notices that the caller acknowledges.
             The notices needed here depend on the values specified in
             ``registration.contact_settings``.
@@ -555,12 +689,34 @@ class RegisterDomainRequest(proto.Message):
             https://cloud.google.com/apis/design/design_patterns#request_validation
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    registration = proto.Field(proto.MESSAGE, number=2, message="Registration",)
-    domain_notices = proto.RepeatedField(proto.ENUM, number=3, enum="DomainNotice",)
-    contact_notices = proto.RepeatedField(proto.ENUM, number=4, enum="ContactNotice",)
-    yearly_price = proto.Field(proto.MESSAGE, number=5, message=money_pb2.Money,)
-    validate_only = proto.Field(proto.BOOL, number=6,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    registration: "Registration" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Registration",
+    )
+    domain_notices: MutableSequence["DomainNotice"] = proto.RepeatedField(
+        proto.ENUM,
+        number=3,
+        enum="DomainNotice",
+    )
+    contact_notices: MutableSequence["ContactNotice"] = proto.RepeatedField(
+        proto.ENUM,
+        number=4,
+        enum="ContactNotice",
+    )
+    yearly_price: money_pb2.Money = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=money_pb2.Money,
+    )
+    validate_only: bool = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
 
 
 class RetrieveTransferParametersRequest(proto.Message):
@@ -575,8 +731,14 @@ class RetrieveTransferParametersRequest(proto.Message):
             ``projects/*/locations/*``.
     """
 
-    domain_name = proto.Field(proto.STRING, number=1,)
-    location = proto.Field(proto.STRING, number=2,)
+    domain_name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    location: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class RetrieveTransferParametersResponse(proto.Message):
@@ -588,8 +750,10 @@ class RetrieveTransferParametersResponse(proto.Message):
             method.
     """
 
-    transfer_parameters = proto.Field(
-        proto.MESSAGE, number=1, message="TransferParameters",
+    transfer_parameters: "TransferParameters" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="TransferParameters",
     )
 
 
@@ -610,7 +774,7 @@ class TransferDomainRequest(proto.Message):
             domain's current DNS service does not cease upon transfer,
             as is often the case for DNS services provided for free by
             the registrar.
-        contact_notices (Sequence[google.cloud.domains_v1.types.ContactNotice]):
+        contact_notices (MutableSequence[google.cloud.domains_v1.types.ContactNotice]):
             The list of contact notices that you acknowledge. The
             notices needed here depend on the values specified in
             ``registration.contact_settings``.
@@ -627,14 +791,34 @@ class TransferDomainRequest(proto.Message):
             transferring the domain.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    registration = proto.Field(proto.MESSAGE, number=2, message="Registration",)
-    contact_notices = proto.RepeatedField(proto.ENUM, number=3, enum="ContactNotice",)
-    yearly_price = proto.Field(proto.MESSAGE, number=4, message=money_pb2.Money,)
-    authorization_code = proto.Field(
-        proto.MESSAGE, number=5, message="AuthorizationCode",
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    registration: "Registration" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Registration",
+    )
+    contact_notices: MutableSequence["ContactNotice"] = proto.RepeatedField(
+        proto.ENUM,
+        number=3,
+        enum="ContactNotice",
+    )
+    yearly_price: money_pb2.Money = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=money_pb2.Money,
+    )
+    authorization_code: "AuthorizationCode" = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="AuthorizationCode",
+    )
+    validate_only: bool = proto.Field(
+        proto.BOOL,
+        number=6,
     )
-    validate_only = proto.Field(proto.BOOL, number=6,)
 
 
 class ListRegistrationsRequest(proto.Message):
@@ -673,17 +857,29 @@ class ListRegistrationsRequest(proto.Message):
             ``(state=SUSPENDED) OR (issue:*)``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListRegistrationsResponse(proto.Message):
     r"""Response for the ``ListRegistrations`` method.
 
     Attributes:
-        registrations (Sequence[google.cloud.domains_v1.types.Registration]):
+        registrations (MutableSequence[google.cloud.domains_v1.types.Registration]):
             A list of ``Registration``\ s.
         next_page_token (str):
             When present, there are more results to retrieve. Set
@@ -695,10 +891,15 @@ class ListRegistrationsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    registrations = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="Registration",
+    registrations: MutableSequence["Registration"] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Registration",
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetRegistrationRequest(proto.Message):
@@ -710,7 +911,10 @@ class GetRegistrationRequest(proto.Message):
             format ``projects/*/locations/*/registrations/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateRegistrationRequest(proto.Message):
@@ -725,9 +929,15 @@ class UpdateRegistrationRequest(proto.Message):
             are being updated, the ``update_mask`` is ``"labels"``.
     """
 
-    registration = proto.Field(proto.MESSAGE, number=1, message="Registration",)
-    update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    registration: "Registration" = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="Registration",
+    )
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -748,12 +958,19 @@ class ConfigureManagementSettingsRequest(proto.Message):
             ``"transfer_lock_state"``.
     """
 
-    registration = proto.Field(proto.STRING, number=1,)
-    management_settings = proto.Field(
-        proto.MESSAGE, number=2, message="ManagementSettings",
+    registration: str = proto.Field(
+        proto.STRING,
+        number=1,
     )
-    update_mask = proto.Field(
-        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
+    management_settings: "ManagementSettings" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="ManagementSettings",
+    )
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -784,12 +1001,24 @@ class ConfigureDnsSettingsRequest(proto.Message):
             updating the DNS settings.
     """
 
-    registration = proto.Field(proto.STRING, number=1,)
-    dns_settings = proto.Field(proto.MESSAGE, number=2, message="DnsSettings",)
-    update_mask = proto.Field(
-        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
+    registration: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    dns_settings: "DnsSettings" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="DnsSettings",
+    )
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=field_mask_pb2.FieldMask,
+    )
+    validate_only: bool = proto.Field(
+        proto.BOOL,
+        number=4,
     )
-    validate_only = proto.Field(proto.BOOL, number=4,)
 
 
 class ConfigureContactSettingsRequest(proto.Message):
@@ -807,7 +1036,7 @@ class ConfigureContactSettingsRequest(proto.Message):
             as a comma-separated list. For example, if only the
             registrant contact is being updated, the ``update_mask`` is
             ``"registrant_contact"``.
-        contact_notices (Sequence[google.cloud.domains_v1.types.ContactNotice]):
+        contact_notices (MutableSequence[google.cloud.domains_v1.types.ContactNotice]):
             The list of contact notices that the caller acknowledges.
             The notices needed here depend on the values specified in
             ``contact_settings``.
@@ -816,13 +1045,29 @@ class ConfigureContactSettingsRequest(proto.Message):
             updating the contact settings.
     """
 
-    registration = proto.Field(proto.STRING, number=1,)
-    contact_settings = proto.Field(proto.MESSAGE, number=2, message="ContactSettings",)
-    update_mask = proto.Field(
-        proto.MESSAGE, number=3, message=field_mask_pb2.FieldMask,
+    registration: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    contact_settings: "ContactSettings" = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="ContactSettings",
+    )
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=field_mask_pb2.FieldMask,
+    )
+    contact_notices: MutableSequence["ContactNotice"] = proto.RepeatedField(
+        proto.ENUM,
+        number=4,
+        enum="ContactNotice",
+    )
+    validate_only: bool = proto.Field(
+        proto.BOOL,
+        number=5,
     )
-    contact_notices = proto.RepeatedField(proto.ENUM, number=4, enum="ContactNotice",)
-    validate_only = proto.Field(proto.BOOL, number=5,)
 
 
 class ExportRegistrationRequest(proto.Message):
@@ -834,7 +1079,10 @@ class ExportRegistrationRequest(proto.Message):
             format ``projects/*/locations/*/registrations/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class DeleteRegistrationRequest(proto.Message):
@@ -846,7 +1094,10 @@ class DeleteRegistrationRequest(proto.Message):
             format ``projects/*/locations/*/registrations/*``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class RetrieveAuthorizationCodeRequest(proto.Message):
@@ -859,7 +1110,10 @@ class RetrieveAuthorizationCodeRequest(proto.Message):
             ``projects/*/locations/*/registrations/*``.
     """
 
-    registration = proto.Field(proto.STRING, number=1,)
+    registration: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ResetAuthorizationCodeRequest(proto.Message):
@@ -872,7 +1126,10 @@ class ResetAuthorizationCodeRequest(proto.Message):
             ``projects/*/locations/*/registrations/*``.
     """
 
-    registration = proto.Field(proto.STRING, number=1,)
+    registration: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class RegisterParameters(proto.Message):
@@ -887,10 +1144,10 @@ class RegisterParameters(proto.Message):
             This value is accurate when obtained by calling
             ``RetrieveRegisterParameters``, but is approximate when
             obtained by calling ``SearchDomains``.
-        supported_privacy (Sequence[google.cloud.domains_v1.types.ContactPrivacy]):
+        supported_privacy (MutableSequence[google.cloud.domains_v1.types.ContactPrivacy]):
             Contact privacy options that the domain
             supports.
-        domain_notices (Sequence[google.cloud.domains_v1.types.DomainNotice]):
+        domain_notices (MutableSequence[google.cloud.domains_v1.types.DomainNotice]):
             Notices about special properties of the
             domain.
         yearly_price (google.type.money_pb2.Money):
@@ -906,13 +1163,30 @@ class RegisterParameters(proto.Message):
         UNSUPPORTED = 3
         UNKNOWN = 4
 
-    domain_name = proto.Field(proto.STRING, number=1,)
-    availability = proto.Field(proto.ENUM, number=2, enum=Availability,)
-    supported_privacy = proto.RepeatedField(
-        proto.ENUM, number=3, enum="ContactPrivacy",
+    domain_name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    availability: Availability = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Availability,
+    )
+    supported_privacy: MutableSequence["ContactPrivacy"] = proto.RepeatedField(
+        proto.ENUM,
+        number=3,
+        enum="ContactPrivacy",
+    )
+    domain_notices: MutableSequence["DomainNotice"] = proto.RepeatedField(
+        proto.ENUM,
+        number=4,
+        enum="DomainNotice",
+    )
+    yearly_price: money_pb2.Money = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=money_pb2.Money,
     )
-    domain_notices = proto.RepeatedField(proto.ENUM, number=4, enum="DomainNotice",)
-    yearly_price = proto.Field(proto.MESSAGE, number=5, message=money_pb2.Money,)
 
 
 class TransferParameters(proto.Message):
@@ -926,7 +1200,7 @@ class TransferParameters(proto.Message):
         current_registrar (str):
             The registrar that currently manages the
             domain.
-        name_servers (Sequence[str]):
+        name_servers (MutableSequence[str]):
             The name servers that currently store the
             configuration of the domain.
         transfer_lock_state (google.cloud.domains_v1.types.TransferLockState):
@@ -934,7 +1208,7 @@ class TransferParameters(proto.Message):
             lock. For a transfer to succeed, this must show
             ``UNLOCKED``. To unlock a domain, go to its current
             registrar.
-        supported_privacy (Sequence[google.cloud.domains_v1.types.ContactPrivacy]):
+        supported_privacy (MutableSequence[google.cloud.domains_v1.types.ContactPrivacy]):
             Contact privacy options that the domain
             supports.
         yearly_price (google.type.money_pb2.Money):
@@ -942,14 +1216,33 @@ class TransferParameters(proto.Message):
             year.
     """
 
-    domain_name = proto.Field(proto.STRING, number=1,)
-    current_registrar = proto.Field(proto.STRING, number=2,)
-    name_servers = proto.RepeatedField(proto.STRING, number=3,)
-    transfer_lock_state = proto.Field(proto.ENUM, number=4, enum="TransferLockState",)
-    supported_privacy = proto.RepeatedField(
-        proto.ENUM, number=5, enum="ContactPrivacy",
+    domain_name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    current_registrar: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    name_servers: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    transfer_lock_state: "TransferLockState" = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum="TransferLockState",
+    )
+    supported_privacy: MutableSequence["ContactPrivacy"] = proto.RepeatedField(
+        proto.ENUM,
+        number=5,
+        enum="ContactPrivacy",
+    )
+    yearly_price: money_pb2.Money = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=money_pb2.Money,
     )
-    yearly_price = proto.Field(proto.MESSAGE, number=6, message=money_pb2.Money,)
 
 
 class AuthorizationCode(proto.Message):
@@ -962,7 +1255,10 @@ class AuthorizationCode(proto.Message):
             registrar.
     """
 
-    code = proto.Field(proto.STRING, number=1,)
+    code: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class OperationMetadata(proto.Message):
@@ -986,12 +1282,32 @@ class OperationMetadata(proto.Message):
             API version used to start the operation.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    target = proto.Field(proto.STRING, number=3,)
-    verb = proto.Field(proto.STRING, number=4,)
-    status_detail = proto.Field(proto.STRING, number=5,)
-    api_version = proto.Field(proto.STRING, number=6,)
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    target: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    verb: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    status_detail: str = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    api_version: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
