@@ -15,26 +15,22 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.longrunning import operations_pb2  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+from google.cloud.domains_v1beta1 import gapic_version as package_version
 from google.cloud.domains_v1beta1.types import domains
-from google.longrunning import operations_pb2  # type: ignore
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-domains",).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 class DomainsTransport(abc.ABC):
@@ -48,12 +44,13 @@ class DomainsTransport(abc.ABC):
         self,
         *,
         host: str = DEFAULT_HOST,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
+        api_audience: Optional[str] = None,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -80,10 +77,6 @@ class DomainsTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
-        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
-        if ":" not in host:
-            host += ":443"
-        self._host = host
 
         scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
 
@@ -105,6 +98,11 @@ class DomainsTransport(abc.ABC):
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
             )
+            # Don't apply audience if the credentials file passed from user.
+            if hasattr(credentials, "with_gdch_audience"):
+                credentials = credentials.with_gdch_audience(
+                    api_audience if api_audience else host
+                )
 
         # If the credentials are service account credentials, then always try to use self signed JWT.
         if (
@@ -117,11 +115,18 @@ class DomainsTransport(abc.ABC):
         # Save the credentials.
         self._credentials = credentials
 
+        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
+        if ":" not in host:
+            host += ":443"
+        self._host = host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.search_domains: gapic_v1.method.wrap_method(
-                self.search_domains, default_timeout=None, client_info=client_info,
+                self.search_domains,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.retrieve_register_parameters: gapic_v1.method.wrap_method(
                 self.retrieve_register_parameters,
@@ -129,7 +134,9 @@ class DomainsTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.register_domain: gapic_v1.method.wrap_method(
-                self.register_domain, default_timeout=None, client_info=client_info,
+                self.register_domain,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.retrieve_transfer_parameters: gapic_v1.method.wrap_method(
                 self.retrieve_transfer_parameters,
@@ -137,16 +144,24 @@ class DomainsTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.transfer_domain: gapic_v1.method.wrap_method(
-                self.transfer_domain, default_timeout=None, client_info=client_info,
+                self.transfer_domain,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.list_registrations: gapic_v1.method.wrap_method(
-                self.list_registrations, default_timeout=None, client_info=client_info,
+                self.list_registrations,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_registration: gapic_v1.method.wrap_method(
-                self.get_registration, default_timeout=None, client_info=client_info,
+                self.get_registration,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.update_registration: gapic_v1.method.wrap_method(
-                self.update_registration, default_timeout=None, client_info=client_info,
+                self.update_registration,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.configure_management_settings: gapic_v1.method.wrap_method(
                 self.configure_management_settings,
@@ -164,10 +179,14 @@ class DomainsTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.export_registration: gapic_v1.method.wrap_method(
-                self.export_registration, default_timeout=None, client_info=client_info,
+                self.export_registration,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.delete_registration: gapic_v1.method.wrap_method(
-                self.delete_registration, default_timeout=None, client_info=client_info,
+                self.delete_registration,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.retrieve_authorization_code: gapic_v1.method.wrap_method(
                 self.retrieve_authorization_code,
@@ -184,9 +203,9 @@ class DomainsTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -339,5 +358,9 @@ class DomainsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("DomainsTransport",)
